@@ -3,7 +3,6 @@
 # SPDX-FileCopyrightText: 2023 Fushan Wen <qydwhotmail@gmail.com>
 # SPDX-License-Identifier: MIT
 
-import os
 import unittest
 from typing import Final
 
@@ -31,10 +30,10 @@ class CalendarTest(unittest.TestCase):
         options.set_capability("environ", {
             "LC_ALL": "en_US.UTF-8",
             "QT_FATAL_WARNINGS": "1",
-            "QT_LOGGING_RULES": "qt.accessibility.atspi.warning=false;kf.plasma.core.warning=false;kf.windowsystem.warning=false;kf.kirigami.platform.warning=false",
+            "QT_LOGGING_RULES": "qt.accessibility.atspi.warning=false",
         })
         options.set_capability("timeouts", {'implicit': 10000})
-        cls.driver = webdriver.Remote(command_executor=f'http://127.0.0.1:{os.getenv("FLASK_PORT", "4723")}', options=options)
+        cls.driver = webdriver.Remote(command_executor='http://127.0.0.1:4723', options=options)
 
     def tearDown(self) -> None:
         """
