@@ -3,7 +3,8 @@
 # SPDX-FileCopyrightText: 2023 Fushan Wen <qydwhotmail@gmail.com>
 # SPDX-License-Identifier: MIT
 
-import os
+import subprocess
+import time
 import unittest
 from typing import Final
 
@@ -33,7 +34,7 @@ class KCMFontsTest(unittest.TestCase):
         options.set_capability("environ", {
             "LC_ALL": "en_US.UTF-8",
         })
-        cls.driver = webdriver.Remote(command_executor=f'http://127.0.0.1:{os.getenv("FLASK_PORT", "4723")}', options=options)
+        cls.driver = webdriver.Remote(command_executor='http://127.0.0.1:4723', options=options)
 
     def tearDown(self) -> None:
         """
@@ -48,6 +49,12 @@ class KCMFontsTest(unittest.TestCase):
         Make sure to terminate the driver again, lest it dangles.
         """
         cls.driver.find_element(AppiumBy.XPATH, "//*[@name='Close' and contains(@accessibility-id, 'Button')]").click()
+        for _ in range(10):
+            try:
+                subprocess.check_call(["pidof", f"kcmshell{KDE_VERSION}"])
+            except subprocess.CalledProcessError:
+                break
+            time.sleep(1)
         cls.driver.quit()
 
     def test_0_open(self) -> None:
