@@ -22,11 +22,13 @@
 #include <KNotificationJobUiDelegate>
 #include <KPropertiesDialog>
 #include <KProtocolInfo>
+#include <KRecentDocument>
 
 #include <KIO/DesktopExecParser>
 #include <PlasmaActivities/Stats/Cleaning>
 #include <PlasmaActivities/Stats/ResultSet>
 #include <PlasmaActivities/Stats/Terms>
+#include <algorithm>
 
 #include "containmentinterface.h"
 
@@ -110,7 +112,7 @@ QVariantList createActionListForFileItem(const KFileItem &fileItem)
 bool handleFileItemAction(const KFileItem &fileItem, const QString &actionId, const QVariant &argument, bool *close)
 {
     if (actionId == QLatin1String("_kicker_fileItem_properties")) {
-        KPropertiesDialog *dlg = new KPropertiesDialog(fileItem, QApplication::activeWindow());
+        auto *dlg = new KPropertiesDialog(fileItem, QApplication::activeWindow());
         dlg->setAttribute(Qt::WA_DeleteOnClose);
         dlg->show();
 
@@ -341,6 +343,8 @@ bool handleRecentDocumentAction(KService::Ptr service, const QString &actionId,
             return false;
         }
 
+        KRecentDocument::removeApplication(storageId);
+
         // clang-format off
         auto query = UsedResources
             | Agent(storageId)
@@ -482,7 +486,7 @@ bool handleAdditionalAppActions(const QString &actionId, const KService::Ptr &se
         return false;
     }
     const auto actions = actionProvider.actions();
-    auto action = std::find_if(actions.begin(), actions.end(), [&actionId](const KServiceAction &action) {
+    auto action = std::ranges::find_if(actions, [&actionId](const KServiceAction &action) {
         return action.name() == actionId;
     });
     if (action == actions.end()) {
