@@ -12,6 +12,8 @@
 
 #include "plasmoidregistry.h"
 #include "sortedsystemtraymodel.h"
+#include "statusnotifieritemhost.h"
+#include "statusnotifieritemsource.h"
 #include "systemtraymodel.h"
 #include "systemtraysettings.h"
 
@@ -29,11 +31,11 @@
 #include <Plasma/Applet>
 #include <Plasma/Corona>
 #include <Plasma/PluginLoader>
-#include <Plasma5Support/ServiceJob>
 
 #include <KAcceleratorManager>
 #include <KActionCollection>
 #include <KSharedConfig>
+#include <KWaylandExtras>
 #include <KWindowSystem>
 
 using namespace Qt::StringLiterals;
@@ -58,12 +60,7 @@ void SystemTray::init()
 
     Containment::init();
 
-    m_settings = new SystemTraySettings(configScheme(), this);
-    connect(m_settings, &SystemTraySettings::enabledPluginsChanged, this, &SystemTray::onEnabledAppletsChanged);
-
-    m_plasmoidRegistry = new PlasmoidRegistry(m_settings, this);
-    connect(m_plasmoidRegistry, &PlasmoidRegistry::plasmoidEnabled, this, &SystemTray::startApplet);
-    connect(m_plasmoidRegistry, &PlasmoidRegistry::plasmoidStopped, this, &SystemTray::stopApplet);
+    initSettingsAndRegistry();
 
     // we don't want to automatically propagate the activated signal from the Applet to the Containment
     // even if SystemTray is of type Containment, it is de facto Applet and should act like one
@@ -85,11 +82,25 @@ void SystemTray::init()
     }
 }
 
+void SystemTray::initSettingsAndRegistry()
+{
+    if (!m_settings) {
+        m_settings = new SystemTraySettings(configScheme(), this);
+        connect(m_settings, &SystemTraySettings::enabledPluginsChanged, this, &SystemTray::onEnabledAppletsChanged);
+    }
+
+    if (!m_plasmoidRegistry) {
+        m_plasmoidRegistry = new PlasmoidRegistry(m_settings, this);
+        connect(m_plasmoidRegistry, &PlasmoidRegistry::plasmoidEnabled, this, &SystemTray::startApplet);
+        connect(m_plasmoidRegistry, &PlasmoidRegistry::plasmoidStopped, this, &SystemTray::stopApplet);
+    }
+}
+
 void SystemTray::migrateFromSystrayContainer()
 {
     // Search the old systray containment config group
     KConfigGroup rootCg(corona()->config(), QStringLiteral("Containments"));
-    // NOTE: this function is called from tyhe constructor, so we can't use config() yet
+    // NOTE: this function is called from the constructor, so we can't use config() yet
     KConfigGroup ownCg = KConfigGroup(config());
     // old Configuration group of the old systray applet
     KConfigGroup oldAppletCg(&ownCg, QStringLiteral("Configuration"));
@@ -168,6 +179,7 @@ void SystemTray::restoreContents(KConfigGroup &group)
         }
     }
 
+    initSettingsAndRegistry();
     m_plasmoidRegistry->init();
 }
 
@@ -177,7 +189,7 @@ void SystemTray::showPlasmoidMenu(QQuickItem *appletInterface, int x, int y)
         return;
     }
 
-    Plasma::Applet *applet = appletInterface->property("_plasma_applet").value<Plasma::Applet *>();
+    auto *applet = appletInterface->property("_plasma_applet").value<Plasma::Applet *>();
 
     QPointF pos = appletInterface->mapToScene(QPointF(x, y));
 
@@ -187,7 +199,7 @@ void SystemTray::showPlasmoidMenu(QQuickItem *appletInterface, int x, int y)
         pos = QPoint();
     }
 
-    QMenu *desktopMenu = new QMenu;
+    auto *desktopMenu = new QMenu;
     connect(this, &QObject::destroyed, desktopMenu, &QMenu::close);
     desktopMenu->setAttribute(Qt::WA_DeleteOnClose);
 
@@ -240,77 +252,10 @@ void SystemTray::showPlasmoidMenu(QQuickItem *appletInterface, int x, int y)
     desktopMenu->popup(pos.toPoint());
 }
 
-void SystemTray::showStatusNotifierContextMenu(KJob *job, QQuickItem *statusNotifierIcon)
-{
-    if (QCoreApplication::closingDown() || !statusNotifierIcon) {
-        // apparently an edge case can be triggered due to the async nature of all this
-        // see: https://bugs.kde.org/show_bug.cgi?id=251977
-        return;
-    }
-
-    Plasma5Support::ServiceJob *sjob = qobject_cast<Plasma5Support::ServiceJob *>(job);
-    if (!sjob) {
-        return;
-    }
-
-    QMenu *menu = qobject_cast<QMenu *>(sjob->result().value<QObject *>());
-
-    if (menu && !menu->isEmpty()) {
-        menu->adjustSize();
-        const auto parameters = sjob->parameters();
-        int x = parameters[QStringLiteral("x")].toInt();
-        int y = parameters[QStringLiteral("y")].toInt();
-
-        // try tofind the icon screen coordinates, and adjust the position as a poor
-        // man's popupPosition
-
-        QRect screenItemRect(statusNotifierIcon->mapToScene(QPointF(0, 0)).toPoint(), QSize(statusNotifierIcon->width(), statusNotifierIcon->height()));
-
-        if (statusNotifierIcon->window()) {
-            screenItemRect.moveTopLeft(statusNotifierIcon->window()->mapToGlobal(screenItemRect.topLeft()));
-        }
-
-        switch (location()) {
-        case Plasma::Types::LeftEdge:
-            x = screenItemRect.right();
-            y = screenItemRect.top();
-            break;
-        case Plasma::Types::RightEdge:
-            x = screenItemRect.left() - menu->width();
-            y = screenItemRect.top();
-            break;
-        case Plasma::Types::TopEdge:
-            x = screenItemRect.left();
-            y = screenItemRect.bottom();
-            break;
-        case Plasma::Types::BottomEdge:
-            x = screenItemRect.left();
-            y = screenItemRect.top() - menu->height();
-            break;
-        default:
-            x = screenItemRect.left();
-            if (screenItemRect.top() - menu->height() >= statusNotifierIcon->window()->screen()->geometry().top()) {
-                y = screenItemRect.top() - menu->height();
-            } else {
-                y = screenItemRect.bottom();
-            }
-        }
-
-        KAcceleratorManager::manage(menu);
-        menu->winId();
-        menu->windowHandle()->setTransientParent(statusNotifierIcon->window());
-        menu->popup(QPoint(x, y));
-        // Workaround for QTBUG-59044
-        if (auto item = statusNotifierIcon->window()->mouseGrabberItem()) {
-            item->ungrabMouse();
-        }
-    }
-}
-
 QPointF SystemTray::popupPosition(QQuickItem *visualParent, int x, int y)
 {
     if (!visualParent) {
-        return QPointF(0, 0);
+        return {0, 0};
     }
 
     QPointF pos = visualParent->mapToScene(QPointF(x, y));
@@ -491,7 +436,134 @@ void SystemTray::stackItemAfter(QQuickItem *newItem, QQuickItem *afterItem)
     newItem->stackAfter(afterItem);
 }
 
-K_PLUGIN_CLASS(SystemTray)
+void SystemTray::activate(const QString &service, QPoint pos, QQuickItem *statusNotifierIcon)
+{
+    const auto source = StatusNotifierItemHost::self()->itemForService(service);
+
+    connect(
+        source,
+        &StatusNotifierItemSource::activateResult,
+        this,
+        [this, service, pos, statusNotifierIcon](bool res) {
+            if (!res) {
+                // On error try to invoke the context menu.
+                // Workaround primarily for apps using libappindicator.
+                openContextMenu(service, pos, statusNotifierIcon);
+            }
+        },
+        Qt::SingleShotConnection);
+
+    QWindow *window = nullptr;
+    if (KWindowSystem::isPlatformX11()) {
+        source->activate(pos.x(), pos.y());
+        return;
+    }
+
+    auto tokenFuture = KWaylandExtras::xdgActivationToken(window, {});
+    tokenFuture.then(this, [source, service, pos](const QString &token) {
+        source->provideXdgActivationToken(token);
+        source->activate(pos.x(), pos.y());
+    });
+}
+
+void SystemTray::secondaryActivate(const QString &service, QPoint pos)
+{
+    const auto source = StatusNotifierItemHost::self()->itemForService(service);
+
+    QWindow *window = nullptr;
+    if (KWindowSystem::isPlatformX11()) {
+        source->secondaryActivate(pos.x(), pos.y());
+        return;
+    }
+
+    auto tokenFuture = KWaylandExtras::xdgActivationToken(window, {});
+    tokenFuture.then(this, [source, pos](const QString &token) {
+        source->provideXdgActivationToken(token);
+        source->secondaryActivate(pos.x(), pos.y());
+    });
+}
+
+void SystemTray::openContextMenu(const QString &service, QPoint pos, QQuickItem *statusNotifierIcon)
+{
+    const auto source = StatusNotifierItemHost::self()->itemForService(service);
+
+    connect(
+        source,
+        &StatusNotifierItemSource::contextMenuReady,
+        this,
+        [this, statusNotifierIcon, pos](QMenu *menu) {
+            if (menu && !menu->isEmpty()) {
+                menu->adjustSize();
+                int x = pos.x();
+                int y = pos.y();
+
+                // try tofind the icon screen coordinates, and adjust the position as a poor
+                // man's popupPosition
+
+                QRect screenItemRect(statusNotifierIcon->mapToScene(QPointF(0, 0)).toPoint(), QSize(statusNotifierIcon->width(), statusNotifierIcon->height()));
+
+                if (statusNotifierIcon->window()) {
+                    screenItemRect.moveTopLeft(statusNotifierIcon->window()->mapToGlobal(screenItemRect.topLeft()));
+                }
+
+                switch (location()) {
+                case Plasma::Types::LeftEdge:
+                    x = screenItemRect.right();
+                    y = screenItemRect.top();
+                    break;
+                case Plasma::Types::RightEdge:
+                    x = screenItemRect.left() - menu->width();
+                    y = screenItemRect.top();
+                    break;
+                case Plasma::Types::TopEdge:
+                    x = screenItemRect.left();
+                    y = screenItemRect.bottom();
+                    break;
+                case Plasma::Types::BottomEdge:
+                    x = screenItemRect.left();
+                    y = screenItemRect.top() - menu->height();
+                    break;
+                default:
+                    x = screenItemRect.left();
+                    if (screenItemRect.top() - menu->height() >= statusNotifierIcon->window()->screen()->geometry().top()) {
+                        y = screenItemRect.top() - menu->height();
+                    } else {
+                        y = screenItemRect.bottom();
+                    }
+                }
+
+                KAcceleratorManager::manage(menu);
+                menu->winId();
+                menu->windowHandle()->setTransientParent(statusNotifierIcon->window());
+                menu->popup(QPoint(x, y));
+                // Workaround for QTBUG-59044
+                if (auto item = statusNotifierIcon->window()->mouseGrabberItem()) {
+                    item->ungrabMouse();
+                }
+            }
+        },
+        Qt::SingleShotConnection);
+
+    QWindow *window = nullptr;
+    if (KWindowSystem::isPlatformX11()) {
+        source->contextMenu(pos.x(), pos.y());
+        return;
+    }
+
+    auto tokenFuture = KWaylandExtras::xdgActivationToken(window, {});
+    tokenFuture.then(this, [source, pos](const QString &token) {
+        source->provideXdgActivationToken(token);
+        source->contextMenu(pos.x(), pos.y());
+    });
+}
+
+void SystemTray::scroll(const QString &service, int delta, const QString &direction)
+{
+    const auto source = StatusNotifierItemHost::self()->itemForService(service);
+    source->scroll(delta, direction);
+}
+
+K_PLUGIN_CLASS_WITH_JSON(SystemTray, "metadata.json")
 
 #include "systemtray.moc"
 
