@@ -281,6 +281,11 @@ void Output::kde_output_device_v2_uuid(const QString &uuid)
     Q_EMIT uuidAdded();
 }
 
+void Output::kde_output_device_v2_mode(struct ::kde_output_device_mode_v2 *mode)
+{
+    kde_output_device_mode_v2_destroy(mode);
+}
+
 KdedDeviceNotifications::KdedDeviceNotifications(QObject *parent, const QList<QVariant> &)
     : KDEDModule(parent)
 {
@@ -319,18 +324,18 @@ void KdedDeviceNotifications::setupWaylandOutputListener()
         auto *self = static_cast<KdedDeviceNotifications *>(data);
         if (qstrcmp(interface, "kde_output_device_v2") == 0) {
             const bool initialOutputsReceived = self->m_initialOutputsReceived;
-            auto &out = self->m_outputs.emplace_back(std::make_unique<Output>(name));
+            Output *output = self->m_outputs.emplace_back(std::make_unique<Output>(name)).get();
             // Notify after the UUID's are resolved, and add it to our timed list
-            connect(out.get(), &Output::uuidAdded, self, [&out, self, initialOutputsReceived]() {
+            connect(output, &Output::uuidAdded, self, [output, self, initialOutputsReceived]() {
                 if (initialOutputsReceived) {
-                    const QString uuid = out->uuid();
+                    const QString uuid = output->uuid();
                     // If we recently just removed this output, it wasn't actually physically disconnected
                     if (!self->m_recentlyRemovedOutputs.removeOne(uuid)) {
                         self->notifyOutputAdded();
                     }
                 }
             });
-            out->init(registry, name, version);
+            output->init(registry, name, version);
         }
     };
     auto globalRemoved = [](void *data, wl_registry *registry, uint32_t name) {
@@ -359,10 +364,10 @@ void KdedDeviceNotifications::setupWaylandOutputListener()
 
     // Suppress notifications until the initial list of outputs has been received.
     auto syncDone = [](void *data, struct wl_callback *wl_callback, uint32_t callback_data) {
-        Q_UNUSED(wl_callback);
         Q_UNUSED(callback_data);
         auto *self = static_cast<KdedDeviceNotifications *>(data);
         self->m_initialOutputsReceived = true;
+        wl_callback_destroy(wl_callback);
     };
     auto syncCallback = wl_display_sync(display);
     static const wl_callback_listener syncCallbackListener{syncDone};
