@@ -5,32 +5,38 @@
 */
 
 #include <QGuiApplication>
-#include <QSessionManager>
 
+#include <KAboutData>
+#include <KCrash>
+#include <KDBusService>
 #include <KWindowSystem>
 
+#include "config-workspace.h"
 #include "menuproxy.h"
 
+using namespace Qt::StringLiterals;
+
 int main(int argc, char **argv)
 {
     qputenv("QT_QPA_PLATFORM", "xcb");
 
     QGuiApplication::setDesktopSettingsAware(false);
+    QCoreApplication::setAttribute(Qt::AA_DisableSessionManager);
 
     QGuiApplication app(argc, argv);
 
     if (!KWindowSystem::isPlatformX11()) {
-        qFatal("qdbusmenuproxy is only useful XCB. Aborting");
+        qFatal("gmenudbusmenuproxy is only useful XCB. Aborting");
     }
 
-    auto disableSessionManagement = [](QSessionManager &sm) {
-        sm.setRestartHint(QSessionManager::RestartNever);
-    };
-    QObject::connect(&app, &QGuiApplication::commitDataRequest, disableSessionManagement);
-    QObject::connect(&app, &QGuiApplication::saveStateRequest, disableSessionManagement);
+    KAboutData about(QStringLiteral("gmenudbusmenuproxy"), QString(), QStringLiteral(WORKSPACE_VERSION_STRING));
+    KAboutData::setApplicationData(about);
+
+    KCrash::initialize();
 
     app.setQuitOnLastWindowClosed(false);
 
+    KDBusService service(KDBusService::Unique);
     MenuProxy proxy;
 
     return app.exec();
