@@ -149,7 +149,7 @@ QColor KCMColors::accentColor() const
 {
     const QColor color = colorsSettings()->accentColor();
     if (!color.isValid()) {
-        return QColor(Qt::transparent);
+        return {Qt::transparent};
     }
     return color;
 }
@@ -399,29 +399,19 @@ void KCMColors::editScheme(const QString &schemeName, QQuickItem *ctx)
                     Qt::SingleShotConnection);
 
                 m_waitForXdgActivation = true;
-                const int lastSerial = KWaylandExtras::lastInputSerial(actualWindow);
-                KWaylandExtras::requestXdgActivationToken(actualWindow, lastSerial, QStringLiteral("org.kde.kcolorschemeeditor"));
-                connect(
-                    KWaylandExtras::self(),
-                    &KWaylandExtras::xdgActivationTokenArrived,
-                    this,
-                    [this, lastSerial](int serial, const QString &token) {
-                        if (serial != lastSerial) {
-                            return;
-                        }
+                auto tokenFuture = KWaylandExtras::xdgActivationToken(actualWindow, QStringLiteral("org.kde.kcolorschemeeditor"));
+                tokenFuture.then(this, [this](const QString &token) {
+                    if (!token.isEmpty()) {
+                        QProcessEnvironment environment = QProcessEnvironment::systemEnvironment();
+                        environment.insert(QStringLiteral("XDG_ACTIVATION_TOKEN"), token);
+                        m_editDialogProcess->setProcessEnvironment(environment);
+                    }
 
-                        if (!token.isEmpty()) {
-                            QProcessEnvironment environment = QProcessEnvironment::systemEnvironment();
-                            environment.insert(QStringLiteral("XDG_ACTIVATION_TOKEN"), token);
-                            m_editDialogProcess->setProcessEnvironment(environment);
-                        }
-
-                        m_waitForXdgActivation = false;
-                        if (!m_waitForXdgForeign) {
-                            m_editDialogProcess->start();
-                        }
-                    },
-                    Qt::SingleShotConnection);
+                    m_waitForXdgActivation = false;
+                    if (!m_waitForXdgForeign) {
+                        m_editDialogProcess->start();
+                    }
+                });
             }
         }
     }
@@ -506,7 +496,7 @@ void KCMColors::applyWallpaperAccentColor()
     QDBusMessage accentColor = QDBusMessage::createMethodCall(u"org.kde.plasmashell"_s, u"/PlasmaShell"_s, u"org.kde.PlasmaShell"_s, u"color"_s);
     auto const connection = QDBusConnection::connectToBus(QDBusConnection::SessionBus, u"accentColorBus"_s);
     QDBusPendingCall async = connection.asyncCall(accentColor);
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(async, this);
+    auto *watcher = new QDBusPendingCallWatcher(async, this);
 
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &KCMColors::wallpaperAccentColorArrivedSlot);
 }
