@@ -11,6 +11,7 @@
 #include <QCursor>
 #include <QDir>
 #include <QImage>
+#include <algorithm>
 #include <private/qtx11extras_p.h>
 
 #include <X11/Xcursor/Xcursor.h>
@@ -43,7 +44,7 @@ XCursorTheme::XCursorTheme(const QDir &themeDir)
                 sizeList.append(images->images[i]->size);
         };
         XcursorImagesDestroy(images);
-        std::sort(sizeList.begin(), sizeList.end());
+        std::ranges::sort(sizeList);
         m_availableSizes = sizeList;
     }
     if (!sizeList.isEmpty()) {
@@ -196,7 +197,7 @@ QImage XCursorTheme::loadImage(const QString &name, int size) const
         xcimage = xcLoadImage(findAlternative(name), size);
 
     if (!xcimage) {
-        return QImage();
+        return {};
     }
 
     // Convert the XcursorImage to a QImage, and auto-crop it
