@@ -7,6 +7,7 @@
 
 #include "historymodel.h"
 
+#include <algorithm>
 #include <chrono>
 #include <zlib.h>
 
@@ -93,7 +94,7 @@ QString computeUuid(const QMimeData *data)
         }
     }
     if (data->hasImage()) {
-        const QImage image = data->imageData().value<QImage>();
+        const auto image = data->imageData().value<QImage>();
         hash.addData(QByteArrayView(reinterpret_cast<const char *>(image.constBits()), image.sizeInBytes()));
     }
     return QString::fromLatin1(hash.result().toHex());
@@ -140,8 +141,10 @@ HistoryModel::HistoryModel()
             [this](const QModelIndex & /*sourceParent*/, int sourceStart, int /*sourceEnd*/, const QModelIndex & /*destinationParent*/, int destinationRow) {
                 Q_EMIT changed(sourceStart == 0 || destinationRow == 0);
             });
-    connect(this, &HistoryModel::dataChanged, this, [this](const QModelIndex &topLeft) {
-        Q_EMIT changed(topLeft.row() == 0); // BUG 494031 the first item does not trigger rowsMoved
+    connect(this, &HistoryModel::dataChanged, this, [this](const QModelIndex &topLeft, const QModelIndex &, const QList<int> &roles) {
+        if (roles.contains(UuidRole)) { // Avoid overriding the current clipboard with async-loaded image data
+            Q_EMIT changed(topLeft.row() == 0); // BUG 494031 the first item does not trigger rowsMoved
+        }
     });
     connect(this, &HistoryModel::modelReset, this, [this] {
         Q_EMIT changed(true);
@@ -190,7 +193,7 @@ void HistoryModel::clear()
     }
     QList<QUrl> deletedDataFolders;
     deletedDataFolders.reserve(m_items.size());
-    std::transform(m_items.cbegin(), m_items.cend(), std::back_inserter(deletedDataFolders), [this](const auto &item) {
+    std::ranges::transform(m_items, std::back_inserter(deletedDataFolders), [this](const auto &item) {
         return QUrl::fromLocalFile(m_dbFolder + u"/data/" + item->uuid() + u'/');
     });
     auto job = KIO::del(deletedDataFolders, KIO::HideProgressInfo);
@@ -367,7 +370,7 @@ QBindable<int> HistoryModel::bindableStarredCount() const
 QVariant HistoryModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid() || index.row() >= m_items.size() || index.column() != 0) {
-        return QVariant();
+        return {};
     }
 
     Q_ASSERT_X(m_db.isOpen(), Q_FUNC_INFO, qPrintable(m_db.lastError().text()));
@@ -417,7 +420,7 @@ QVariant HistoryModel::data(const QModelIndex &index, int role) const
         // frequent database queries if performance becomes an issue with large histories
         return isItemStarred(item->uuid());
     }
-    return QVariant();
+    return {};
 }
 
 bool HistoryModel::setData(const QModelIndex &index, const QVariant &value, int role)
@@ -574,7 +577,7 @@ bool HistoryModel::remove(const QString &uuid)
 
 int HistoryModel::indexOf(const QString &uuid) const
 {
-    auto it = std::find_if(m_items.cbegin(), m_items.cend(), [&uuid](const auto &item) {
+    auto it = std::ranges::find_if(m_items, [&uuid](const auto &item) {
         return item->uuid() == uuid;
     });
     return it == m_items.cend() ? -1 : std::distance(m_items.cbegin(), it);
@@ -591,7 +594,7 @@ int HistoryModel::indexOf(const HistoryItem *item) const
 HistoryItemConstPtr HistoryModel::first() const
 {
     if (m_items.empty()) {
-        return HistoryItemConstPtr();
+        return {};
     }
     return m_items[0];
 }
