@@ -13,18 +13,11 @@ class QWindow;
 
 class HistoryModel;
 
-namespace KWayland
-{
-namespace Client
+namespace KWayland::Client
 {
 class PlasmaShell;
 }
-}
 
-/**
- * Default view of clipboard history.
- *
- */
 class KlipperPopup : public PlasmaQuick::PlasmaWindow
 {
     Q_OBJECT
@@ -38,6 +31,7 @@ public:
     void setPlasmaShell(KWayland::Client::PlasmaShell *plasmashell);
 
     void editCurrentClipboard();
+    void showCurrentBarcode();
 
 public Q_SLOTS:
     void hide();
