@@ -218,7 +218,7 @@ void AbstractNotificationsModel::Private::removeRows(const QList<int> &rows)
     }
 
     QList<int> rowsToBeRemoved(rows);
-    std::sort(rowsToBeRemoved.begin(), rowsToBeRemoved.end());
+    std::ranges::sort(rowsToBeRemoved);
 
     QList<QPair<int, int>> clearQueue;
 
@@ -314,7 +314,7 @@ void AbstractNotificationsModel::setWindow(QWindow *window)
 QVariant AbstractNotificationsModel::data(const QModelIndex &index, int role) const
 {
     if (!checkIndex(index, QAbstractItemModel::CheckIndexOption::IndexIsValid)) {
-        return QVariant();
+        return {};
     }
 
     const Notification &notification = d->notifications.at(index.row());
@@ -427,7 +427,7 @@ QVariant AbstractNotificationsModel::data(const QModelIndex &index, int role) co
         return notification.resident() && notification.timeout() == 0;
     }
 
-    return QVariant();
+    return {};
 }
 
 bool AbstractNotificationsModel::setData(const QModelIndex &index, const QVariant &value, int role)
