@@ -13,9 +13,7 @@ ConcatenateTasksProxyModel::ConcatenateTasksProxyModel(QObject *parent)
 {
 }
 
-ConcatenateTasksProxyModel::~ConcatenateTasksProxyModel()
-{
-}
+ConcatenateTasksProxyModel::~ConcatenateTasksProxyModel() = default;
 
 QModelIndex ConcatenateTasksProxyModel::mapIfaceToSource(const QModelIndex &index) const
 {
@@ -23,3 +21,5 @@ QModelIndex ConcatenateTasksProxyModel::mapIfaceToSource(const QModelIndex &inde
 }
 
 }
+
+#include "moc_concatenatetasksproxymodel.cpp"
