@@ -19,6 +19,7 @@
 #include <QDBusPendingReply>
 #include <QGuiApplication>
 #include <QWaylandClientExtension>
+#include <algorithm>
 
 #include <config-X11.h>
 
@@ -42,9 +43,7 @@ class Q_DECL_HIDDEN VirtualDesktopInfo::Private : public QObject
 
 public:
     Private();
-    virtual ~Private()
-    {
-    }
+    virtual ~Private() = default;
 
     uint refCount = 1;
     // Fall back to true if we get an invalid DBus response when asking for the
@@ -68,6 +67,7 @@ Q_SIGNALS:
     void numberOfDesktopsChanged() const;
     void desktopIdsChanged() const;
     void desktopNamesChanged() const;
+    void desktopPositionsChanged() const;
     void desktopLayoutRowsChanged() const;
     void navigationWrappingAroundChanged() const;
 
@@ -257,6 +257,7 @@ public:
     }
     const QString id;
     QString name;
+    uint position = 0;
 Q_SIGNALS:
     void done();
     void activated();
@@ -266,6 +267,10 @@ protected:
     {
         this->name = name;
     }
+    void org_kde_plasma_virtual_desktop_position(uint32_t index) override
+    {
+        this->position = index;
+    }
     void org_kde_plasma_virtual_desktop_done() override
     {
         Q_EMIT done();
@@ -282,7 +287,7 @@ class PlasmaVirtualDesktopManagement : public QWaylandClientExtensionTemplate<Pl
     Q_OBJECT
 public:
     PlasmaVirtualDesktopManagement()
-        : QWaylandClientExtensionTemplate(2)
+        : QWaylandClientExtensionTemplate(3)
     {
         connect(this, &QWaylandClientExtension::activeChanged, this, [this] {
             if (!isActive()) {
@@ -300,6 +305,7 @@ Q_SIGNALS:
     void desktopCreated(const QString &id, quint32 position);
     void desktopRemoved(const QString &id);
     void rowsChanged(const quint32 rows);
+    void done();
 
 protected:
     void org_kde_plasma_virtual_desktop_management_desktop_created(const QString &desktop_id, uint32_t position) override
@@ -314,6 +320,10 @@ protected:
     {
         Q_EMIT rowsChanged(rows);
     }
+    void org_kde_plasma_virtual_desktop_management_done() override
+    {
+        Q_EMIT done();
+    }
 };
 
 class Q_DECL_HIDDEN VirtualDesktopInfo::WaylandPrivate : public VirtualDesktopInfo::Private
@@ -350,7 +360,7 @@ VirtualDesktopInfo::WaylandPrivate::WaylandPrivate()
 
 auto VirtualDesktopInfo::WaylandPrivate::findDesktop(const QString &id) const
 {
-    return std::find_if(virtualDesktops.begin(), virtualDesktops.end(), [&id](const std::unique_ptr<PlasmaVirtualDesktop> &desktop) {
+    return std::ranges::find_if(virtualDesktops, [&id](const std::unique_ptr<PlasmaVirtualDesktop> &desktop) {
         return desktop->id == id;
     });
 }
@@ -373,6 +383,7 @@ void VirtualDesktopInfo::WaylandPrivate::init()
             Q_EMIT navigationWrappingAroundChanged();
             Q_EMIT desktopIdsChanged();
             Q_EMIT desktopNamesChanged();
+            Q_EMIT desktopPositionsChanged();
             Q_EMIT desktopLayoutRowsChanged();
         }
     });
@@ -387,6 +398,7 @@ void VirtualDesktopInfo::WaylandPrivate::init()
         Q_EMIT numberOfDesktopsChanged();
         Q_EMIT desktopIdsChanged();
         Q_EMIT desktopNamesChanged();
+        Q_EMIT desktopPositionsChanged();
 
         if (currentVirtualDesktop == id) {
             currentVirtualDesktop.clear();
@@ -398,6 +410,24 @@ void VirtualDesktopInfo::WaylandPrivate::init()
         this->rows = rows;
         Q_EMIT desktopLayoutRowsChanged();
     });
+
+    connect(virtualDesktopManagement.get(), &PlasmaVirtualDesktopManagement::done, this, [this]() {
+        bool reordered = false;
+        for (uint i = 0; i < virtualDesktops.size(); ++i) {
+            if (virtualDesktops[i]->position != i) {
+                reordered = true;
+                break;
+            }
+        }
+
+        if (reordered) {
+            std::ranges::sort(virtualDesktops, [](std::unique_ptr<PlasmaVirtualDesktop> &a, std::unique_ptr<PlasmaVirtualDesktop> &b) {
+                return a->position < b->position;
+            });
+
+            Q_EMIT desktopPositionsChanged();
+        }
+    });
 }
 
 void VirtualDesktopInfo::WaylandPrivate::addDesktop(const QString &id, quint32 position)
@@ -407,6 +437,7 @@ void VirtualDesktopInfo::WaylandPrivate::addDesktop(const QString &id, quint32 p
     }
 
     auto desktop = std::make_unique<PlasmaVirtualDesktop>(virtualDesktopManagement->get_virtual_desktop(id), id);
+    desktop->position = position;
 
     connect(desktop.get(), &PlasmaVirtualDesktop::activated, this, [id, this]() {
         currentVirtualDesktop = id;
@@ -422,6 +453,7 @@ void VirtualDesktopInfo::WaylandPrivate::addDesktop(const QString &id, quint32 p
     Q_EMIT numberOfDesktopsChanged();
     Q_EMIT desktopIdsChanged();
     Q_EMIT desktopNamesChanged();
+    Q_EMIT desktopPositionsChanged();
 }
 
 QVariant VirtualDesktopInfo::WaylandPrivate::currentDesktop() const
@@ -436,7 +468,10 @@ int VirtualDesktopInfo::WaylandPrivate::numberOfDesktops() const
 
 quint32 VirtualDesktopInfo::WaylandPrivate::position(const QVariant &desktop) const
 {
-    return std::distance(virtualDesktops.begin(), findDesktop(desktop.toString()));
+    if (auto it = findDesktop(desktop.toString()); it != virtualDesktops.end()) {
+        return (*it)->position;
+    }
+    return 0;
 }
 
 QVariantList VirtualDesktopInfo::WaylandPrivate::desktopIds() const
@@ -444,7 +479,7 @@ QVariantList VirtualDesktopInfo::WaylandPrivate::desktopIds() const
     QVariantList ids;
     ids.reserve(virtualDesktops.size());
 
-    std::transform(virtualDesktops.cbegin(), virtualDesktops.cend(), std::back_inserter(ids), [](const std::unique_ptr<PlasmaVirtualDesktop> &desktop) {
+    std::ranges::transform(virtualDesktops, std::back_inserter(ids), [](const std::unique_ptr<PlasmaVirtualDesktop> &desktop) {
         return desktop->id;
     });
     return ids;
@@ -453,12 +488,12 @@ QVariantList VirtualDesktopInfo::WaylandPrivate::desktopIds() const
 QStringList VirtualDesktopInfo::WaylandPrivate::desktopNames() const
 {
     if (!virtualDesktopManagement->isActive()) {
-        return QStringList();
+        return {};
     }
     QStringList names;
     names.reserve(virtualDesktops.size());
 
-    std::transform(virtualDesktops.cbegin(), virtualDesktops.cend(), std::back_inserter(names), [](const std::unique_ptr<PlasmaVirtualDesktop> &desktop) {
+    std::ranges::transform(virtualDesktops, std::back_inserter(names), [](const std::unique_ptr<PlasmaVirtualDesktop> &desktop) {
         return desktop->name;
     });
     return names;
@@ -530,6 +565,7 @@ VirtualDesktopInfo::VirtualDesktopInfo(QObject *parent)
     connect(d, &VirtualDesktopInfo::Private::numberOfDesktopsChanged, this, &VirtualDesktopInfo::numberOfDesktopsChanged);
     connect(d, &VirtualDesktopInfo::Private::desktopIdsChanged, this, &VirtualDesktopInfo::desktopIdsChanged);
     connect(d, &VirtualDesktopInfo::Private::desktopNamesChanged, this, &VirtualDesktopInfo::desktopNamesChanged);
+    connect(d, &VirtualDesktopInfo::Private::desktopPositionsChanged, this, &VirtualDesktopInfo::desktopPositionsChanged);
     connect(d, &VirtualDesktopInfo::Private::desktopLayoutRowsChanged, this, &VirtualDesktopInfo::desktopLayoutRowsChanged);
 }
 
@@ -538,8 +574,7 @@ VirtualDesktopInfo::~VirtualDesktopInfo()
     --d->refCount;
 
     if (!d->refCount) {
-        delete d;
-        d = nullptr;
+        delete std::exchange(d, nullptr);
     }
 }
 
