@@ -17,6 +17,7 @@
 #include <QTimer>
 #include <QUrl>
 #include <QtWaylandClient/QWaylandClientExtensionTemplate>
+#include <algorithm>
 
 using namespace Qt::StringLiterals;
 
@@ -173,7 +174,7 @@ void WaylandStartupTasksModel::Private::addActivation(PlasmaActivation *activati
         q->endInsertRows();
 
         // Remove the activation if it doesn't finish within certain time interval.
-        QTimer *timeoutTimer = new QTimer(activation);
+        auto *timeoutTimer = new QTimer(activation);
         QObject::connect(timeoutTimer, &QTimer::timeout, q, [this, activation]() {
             removeActivation(activation);
         });
@@ -188,7 +189,7 @@ void WaylandStartupTasksModel::Private::addActivation(PlasmaActivation *activati
 
 void WaylandStartupTasksModel::Private::removeActivation(PlasmaActivation *activation)
 {
-    auto it = std::find_if(startups.begin(), startups.end(), [activation](const Startup &startup) {
+    auto it = std::ranges::find_if(startups, [activation](const Startup &startup) {
         return startup.activation.get() == activation;
     });
     if (it == startups.end()) {
@@ -207,15 +208,13 @@ WaylandStartupTasksModel::WaylandStartupTasksModel(QObject *parent)
     d->init();
 }
 
-WaylandStartupTasksModel::~WaylandStartupTasksModel()
-{
-}
+WaylandStartupTasksModel::~WaylandStartupTasksModel() = default;
 
 QVariant WaylandStartupTasksModel::data(const QModelIndex &index, int role) const
 {
     // Note: when index is valid, its row >= 0, so casting to unsigned is safe
     if (!index.isValid() || static_cast<size_t>(index.row()) >= d->startups.size()) {
-        return QVariant();
+        return {};
     }
 
     const auto &data = d->startups[index.row()];
