@@ -8,10 +8,10 @@
 #include <csignal>
 
 #include <QApplication>
+#include <QCommandLineOption>
+#include <QCommandLineParser>
 #include <QQmlDebuggingEnabler>
 #include <QSurfaceFormat>
-#include <qcommandlineoption.h>
-#include <qcommandlineparser.h>
 
 #include <KDBusService>
 #include <KLocalizedString>
@@ -70,7 +70,7 @@ int main(int argc, char **argv)
         parser.showHelp(1);
     }
 
-    PlasmaWindowedCorona *corona = new PlasmaWindowedCorona(parser.value(shellPluginOption));
+    auto *corona = new PlasmaWindowedCorona(parser.value(shellPluginOption));
 
     const QStringList arguments = parser.positionalArguments();
     QVariantList args;
