@@ -8,7 +8,6 @@
 #include "config-X11.h"
 #include "desktopview.h"
 #include "panelshadows_p.h"
-#include "panelview.h"
 #include "shellcorona.h"
 
 #include <LayerShellQt/Window>
@@ -54,15 +53,14 @@ PanelRulerView::PanelRulerView(Plasma::Containment *containment, PanelView *pane
         m_layerWindow->setKeyboardInteractivity(LayerShellQt::Window::KeyboardInteractivityOnDemand);
         m_layerWindow->setScope(QStringLiteral("dock"));
         m_layerWindow->setCloseOnDismissed(false);
+        m_layerWindow->setScreen(m_panelView->screen());
     }
     setScreen(m_panelView->screen());
 
     connect(this, &PanelRulerView::mainItemChanged, this, &PanelRulerView::syncPanelLocation);
 }
 
-PanelRulerView::~PanelRulerView()
-{
-}
+PanelRulerView::~PanelRulerView() = default;
 
 void PanelRulerView::syncPanelLocation()
 {
@@ -140,8 +138,6 @@ void PanelRulerView::syncPanelLocation()
             break;
         }
 
-        setScreen(screen);
-
         m_layerWindow->setKeyboardInteractivity(LayerShellQt::Window::KeyboardInteractivityOnDemand);
         LayerShellQt::Window::Anchors anchors;
 
@@ -217,7 +213,7 @@ PanelConfigView::PanelConfigView(Plasma::Containment *containment, PanelView *pa
     , m_panelView(panelView)
     , m_sharedQmlEngine(std::make_unique<PlasmaQuick::SharedQmlEngine>(this))
 {
-    ShellCorona *c = qobject_cast<ShellCorona *>(m_containment->corona());
+    auto *c = qobject_cast<ShellCorona *>(m_containment->corona());
     setProperty("restrictedPopupGeometry", QVariant(c->availableScreenRect(m_containment->screen())));
     connect(m_containment, &Plasma::Containment::screenChanged, this, [this, c](int screen) {
         setProperty("restrictedPopupGeometry", QVariant(c->availableScreenRect(screen)));
@@ -262,9 +258,7 @@ PanelConfigView::PanelConfigView(Plasma::Containment *containment, PanelView *pa
     m_focusWindow = qApp->focusWindow();
 }
 
-PanelConfigView::~PanelConfigView()
-{
-}
+PanelConfigView::~PanelConfigView() = default;
 
 void PanelConfigView::init()
 {
@@ -274,7 +268,7 @@ void PanelConfigView::init()
     setMainItem(qobject_cast<QQuickItem *>(m_sharedQmlEngine->rootObject()));
     if (mainItem()) {
         if (m_panelRulerView) {
-            QQuickItem *ruler = mainItem()->property("panelRuler").value<QQuickItem *>();
+            auto *ruler = mainItem()->property("panelRuler").value<QQuickItem *>();
             m_panelRulerView->setMainItem(ruler);
             m_panelRulerView->syncPanelLocation();
         }
@@ -299,7 +293,7 @@ void PanelConfigView::showAddWidgetDialog()
 
 void PanelConfigView::addPanelSpacer()
 {
-    ShellCorona *c = qobject_cast<ShellCorona *>(m_containment->corona());
+    auto *c = qobject_cast<ShellCorona *>(m_containment->corona());
     if (!c) {
         return;
     }
@@ -462,7 +456,7 @@ PanelRulerView *PanelConfigView::panelRulerView()
     }
 
     if (mainItem()) {
-        QQuickItem *ruler = mainItem()->property("panelRuler").value<QQuickItem *>();
+        auto *ruler = mainItem()->property("panelRuler").value<QQuickItem *>();
         m_panelRulerView->setMainItem(ruler);
         m_panelRulerView->syncPanelLocation();
     }
