@@ -183,7 +183,7 @@ PanelView::OpacityMode PanelView::defaultOpacityMode() const
 KConfigGroup PanelView::panelConfig(ShellCorona *corona, Plasma::Containment *containment, QScreen *screen)
 {
     if (!containment || !screen) {
-        return KConfigGroup();
+        return {};
     }
     KConfigGroup views(corona->applicationConfig(), u"PlasmaViews"_s);
     views = KConfigGroup(&views, QStringLiteral("Panel %1").arg(containment->id()));
@@ -199,7 +199,7 @@ KConfigGroup PanelView::panelConfig(ShellCorona *corona, Plasma::Containment *co
 KConfigGroup PanelView::panelConfigDefaults(ShellCorona *corona, Plasma::Containment *containment, QScreen *screen)
 {
     if (!containment || !screen) {
-        return KConfigGroup();
+        return {};
     }
 
     KConfigGroup views(corona->applicationConfig(), u"PlasmaViews"_s);
@@ -458,7 +458,7 @@ QString PanelView::unsupportedConfigurationDescription() const
             "With an NVIDIA GPU on X11, the Floating style and Adaptive opacity mode are known to cause poor window drag and resize performance. Consider "
             "using other settings.");
     }
-    return QString();
+    return {};
 }
 
 void PanelView::fixUnsupportedConfiguration()
@@ -477,11 +477,11 @@ void PanelView::clonePanelTo(Plasma::Types::Location location, QScreen *screen)
 QRect PanelView::relativeConfigRect() const
 {
     if (!m_screenToFollow) {
-        return QRect();
+        return {};
     }
-    PanelConfigView *panelConfigView = qobject_cast<PanelConfigView *>(m_panelConfigView);
+    auto *panelConfigView = qobject_cast<PanelConfigView *>(m_panelConfigView);
     if (!panelConfigView || !panelConfigView->isVisible()) {
-        return QRect();
+        return {};
     }
     const QRect screenGeo = m_screenToFollow->geometry();
     QRect rect = m_panelConfigView->geometry();
@@ -743,7 +743,6 @@ void PanelView::positionAndResizePanel()
     // At least one QWindow setGeometry is needed to avoid a protocol error
     if (m_layerWindow && !size().isEmpty()) {
         m_layerWindow->setDesiredSize(geom.size());
-        setPosition(geom.topLeft());
     } else {
         setGeometry(geom);
     }
@@ -760,7 +759,7 @@ void PanelView::positionAndResizePanel()
 QRect PanelView::dogdeGeometryByDistance(int distance) const
 {
     if (!containment() || !m_screenToFollow) {
-        return QRect();
+        return {};
     }
     const QRect dodgeGeometry = geometryByDistance(distance);
     return dodgeGeometry & m_screenToFollow->geometry();
@@ -769,7 +768,7 @@ QRect PanelView::dogdeGeometryByDistance(int distance) const
 QRect PanelView::geometryByDistance(int distance) const
 {
     if (!containment() || !m_screenToFollow) {
-        return QRect();
+        return {};
     }
 
     const QRect screenGeometry = m_screenToFollow->geometry();
@@ -830,14 +829,14 @@ QRect PanelView::geometryByDistance(int distance) const
 QSize PanelView::preferredSize() const
 {
     if (!m_initCompleted) {
-        return QSize();
+        return {};
     }
 
     // On Wayland when a screen is disconnected and the panel is migrating to a newscreen
     // it can happen a moment where the qscreen gets destroyed before it gets reassigned
     // to the new screen
     if (!m_screenToFollow) {
-        return QSize();
+        return {};
     }
 
     QSize targetSize;
@@ -936,7 +935,7 @@ void PanelView::showConfigurationInterface(Plasma::Applet *applet)
         return;
     }
 
-    Plasma::Containment *cont = qobject_cast<Plasma::Containment *>(applet);
+    auto *cont = qobject_cast<Plasma::Containment *>(applet);
 
     const bool isPanelConfig = (cont && cont == containment() && cont->isContainment());
 
@@ -955,7 +954,7 @@ void PanelView::showConfigurationInterface(Plasma::Applet *applet)
             m_panelConfigView->show();
             m_panelConfigView->requestActivate();
         } else {
-            PanelConfigView *configView = new PanelConfigView(cont, this);
+            auto *configView = new PanelConfigView(cont, this);
             connect(configView, &PanelConfigView::visibleChanged, this, &PanelView::relativeConfigRectChanged);
             connect(configView, &PanelConfigView::visibleChanged, this, &PanelView::userConfiguringChanged);
             connect(configView, &PanelConfigView::geometryChanged, this, &PanelView::relativeConfigRectChanged);
@@ -1001,7 +1000,7 @@ void PanelView::showConfigurationInterface(Plasma::Applet *applet)
 void PanelView::positionConfigView()
 {
     QQuickItem *contObject = PlasmaQuick::AppletQuickItem::itemForApplet(containment());
-    QQuickItem *tb = contObject->property("toolBox").value<QQuickItem *>();
+    auto *tb = contObject->property("toolBox").value<QQuickItem *>();
     if (tb && containment()->formFactor() != Plasma::Types::Vertical) {
         m_panelConfigView->setVisualParent(tb);
     } else {
@@ -1243,8 +1242,9 @@ bool PanelView::event(QEvent *e)
 
     case QEvent::MouseMove:
     case QEvent::MouseButtonPress:
-    case QEvent::MouseButtonRelease: {
-        QMouseEvent *me = static_cast<QMouseEvent *>(e);
+    case QEvent::MouseButtonRelease:
+    case QEvent::MouseButtonDblClick: {
+        auto *me = static_cast<QMouseEvent *>(e);
 
         // first, don't mess with position if the cursor is actually outside the view:
         // somebody is doing a click and drag that must not break when the cursor i outside
@@ -1273,7 +1273,7 @@ bool PanelView::event(QEvent *e)
     }
 
     case QEvent::Wheel: {
-        QWheelEvent *we = static_cast<QWheelEvent *>(e);
+        auto *we = static_cast<QWheelEvent *>(e);
 
         if (!containmentContainsPosition(we->position()) && !m_fakeEventPending) {
             QWheelEvent we2(positionAdjustedForContainment(we->position()),
@@ -1299,7 +1299,7 @@ bool PanelView::event(QEvent *e)
         if (edgeActivated()) {
             m_unhideTimer.stop();
         }
-        QDragEnterEvent *de = static_cast<QDragEnterEvent *>(e);
+        auto *de = static_cast<QDragEnterEvent *>(e);
         if (!containmentContainsPosition(de->position()) && !m_fakeEventPending) {
             QDragEnterEvent de2(positionAdjustedForContainment(de->position()).toPoint(),
                                 de->possibleActions(),
@@ -1322,7 +1322,7 @@ bool PanelView::event(QEvent *e)
         }
         break;
     case QEvent::DragMove: {
-        QDragMoveEvent *de = static_cast<QDragMoveEvent *>(e);
+        auto *de = static_cast<QDragMoveEvent *>(e);
         if (!containmentContainsPosition(de->position()) && !m_fakeEventPending) {
             QDragMoveEvent de2(positionAdjustedForContainment(de->position()).toPoint(), de->possibleActions(), de->mimeData(), de->buttons(), de->modifiers());
 
@@ -1335,7 +1335,7 @@ bool PanelView::event(QEvent *e)
     }
     case QEvent::Drop: {
         m_containsDrag = false;
-        QDropEvent *de = static_cast<QDropEvent *>(e);
+        auto *de = static_cast<QDropEvent *>(e);
         if (!containmentContainsPosition(de->position()) && !m_fakeEventPending) {
             QDropEvent de2(positionAdjustedForContainment(de->position()).toPoint(), de->possibleActions(), de->mimeData(), de->buttons(), de->modifiers());
 
@@ -1360,12 +1360,12 @@ bool PanelView::event(QEvent *e)
     // PanelView does not take focus, but we want any users tracking focus
     // to act like they've lost focus when the panel is clicked and it was not used by another other mouse item
     if (e->type() == QEvent::MouseButtonPress) {
-        QMouseEvent *me = static_cast<QMouseEvent *>(e);
+        auto *me = static_cast<QMouseEvent *>(e);
         if (!me->allPointsGrabbed()) {
             QWindow *focusWindow = qGuiApp->focusWindow();
             if (focusWindow && focusWindow != this && focusWindow->flags().testFlag(Qt::FramelessWindowHint)) {
                 // postEvent takes ownership of the event
-                QFocusEvent *fe = new QFocusEvent(QEvent::FocusOut);
+                auto *fe = new QFocusEvent(QEvent::FocusOut);
                 qGuiApp->postEvent(focusWindow, fe);
             }
         }
@@ -1406,8 +1406,10 @@ QPointF PanelView::positionAdjustedForContainment(const QPointF &point) const
     // We are removing 1 to the e.g. containmentRect.right() - m_rightPadding because the last pixel would otherwise
     // the first one in the margin, and thus the mouse event would be discarded. Instead, the first pixel given by
     // containmentRect.left() + m_leftPadding the first one *not* in the margin, so it work.
-    return QPointF(qBound(containmentRect.left() + m_leftPadding, point.x(), containmentRect.right() - m_rightPadding - 1),
-                   qBound(containmentRect.top() + m_topPadding, point.y(), containmentRect.bottom() - m_bottomPadding - 1));
+    return {
+        qBound(containmentRect.left() + m_leftPadding, point.x(), containmentRect.right() - m_rightPadding - 1),
+        qBound(containmentRect.top() + m_topPadding, point.y(), containmentRect.bottom() - m_bottomPadding - 1),
+    };
 }
 
 void PanelView::updateMask()
@@ -1542,6 +1544,9 @@ bool PanelView::canSetStrut() const
 
 void PanelView::updateExclusiveZone()
 {
+    if (!containment()) {
+        return;
+    }
     if (m_corona->isEditMode() && m_layerWindow && m_layerWindow->exclusionZone() == -1) {
         // We set the exclusve zone to make sure the ruler does not
         // overlap with the panel regardless of the visibility mode,
@@ -1672,6 +1677,7 @@ void PanelView::refreshContainment()
     connect(m_corona, &Plasma::Corona::editModeChanged, this, [this](bool edit) {
         updateExclusiveZone();
     });
+    updateExclusiveZone();
     connect(cont, &Plasma::Containment::userConfiguringChanged, this, [this](bool configuring) {
         if (configuring) {
             showTemporarily();
@@ -1823,7 +1829,7 @@ void PanelView::showTemporarily()
 {
     setAutoHideEnabled(false);
 
-    QTimer *t = new QTimer(this);
+    auto *t = new QTimer(this);
     t->setSingleShot(true);
     t->setInterval(3s);
     connect(t, &QTimer::timeout, this, &PanelView::restoreAutoHide);
