@@ -23,6 +23,7 @@
 #include <X11/Xlib.h>
 #endif
 
+#include <algorithm>
 #include <chrono>
 
 using namespace std::chrono_literals;
@@ -59,9 +60,7 @@ ScreenPool::ScreenPool(QObject *parent)
     reconsiderOutputOrder();
 }
 
-ScreenPool::~ScreenPool()
-{
-}
+ScreenPool::~ScreenPool() = default;
 
 int ScreenPool::idForName(const QString &connector) const
 {
@@ -195,7 +194,7 @@ void ScreenPool::insertSortedScreen(QScreen *screen)
         // This should happen only when a fake screen isn't anymore
         return;
     }
-    auto before = std::find_if(m_sizeSortedScreens.begin(), m_sizeSortedScreens.end(), [this, screen](QScreen *otherScreen) {
+    auto before = std::ranges::find_if(m_sizeSortedScreens, [this, screen](QScreen *otherScreen) {
         return (screen->geometry().width() > otherScreen->geometry().width() && screen->geometry().height() > otherScreen->geometry().height())
             || idForName(screen->name()) < idForName(otherScreen->name());
     });
@@ -367,7 +366,7 @@ void ScreenPool::screenInvariants()
     // Is the primary screen available? TODO: it can be redundant
     // Q_ASSERT(m_availableScreens.contains(primaryScreen()));
 
-    // QScreen bookeeping integrity
+    // QScreen bookkeeping integrity
     auto allScreens = qGuiApp->screens();
     // Do we actually track every screen?
     // (m_availableScreens.count() + m_redundantScreens.count() must be less or equal
