@@ -79,7 +79,7 @@ QStringList Applet::configKeys() const
         return d->configGroup.keyList();
     }
 
-    return QStringList();
+    return {};
 }
 
 QStringList Applet::configGroups() const
@@ -88,7 +88,7 @@ QStringList Applet::configGroups() const
         return d->configGroup.groupList();
     }
 
-    return QStringList();
+    return {};
 }
 
 QVariant Applet::readConfig(const QString &key, const QJSValue &def) const
@@ -96,7 +96,7 @@ QVariant Applet::readConfig(const QString &key, const QJSValue &def) const
     if (d->configGroup.isValid()) {
         return d->configGroup.readEntry(key, def.toVariant());
     } else {
-        return QVariant();
+        return {};
     }
 }
 
@@ -105,7 +105,7 @@ void Applet::writeConfig(const QString &key, const QJSValue &value)
     if (d->configGroup.isValid()) {
         if (d->inWallpaperConfig) {
             // hacky, but only way to make the wallpaper react immediately
-            QObject *wallpaperGraphicsObject = applet()->property("wallpaperGraphicsObject").value<QObject *>();
+            auto *wallpaperGraphicsObject = applet()->property("wallpaperGraphicsObject").value<QObject *>();
             if (wallpaperGraphicsObject) {
                 auto *config = static_cast<QQmlPropertyMap *>(wallpaperGraphicsObject->property("configuration").value<QObject *>());
                 config->setProperty(key.toLatin1().constData(), value.toVariant());
@@ -157,7 +157,7 @@ QStringList Applet::globalConfigKeys() const
         return d->globalConfigGroup.keyList();
     }
 
-    return QStringList();
+    return {};
 }
 
 QStringList Applet::globalConfigGroups() const
@@ -166,7 +166,7 @@ QStringList Applet::globalConfigGroups() const
         return d->globalConfigGroup.groupList();
     }
 
-    return QStringList();
+    return {};
 }
 
 QVariant Applet::readGlobalConfig(const QString &key, const QJSValue &def) const
@@ -174,7 +174,7 @@ QVariant Applet::readGlobalConfig(const QString &key, const QJSValue &def) const
     if (d->globalConfigGroup.isValid()) {
         return d->globalConfigGroup.readEntry(key, def.toVariant());
     } else {
-        return QVariant();
+        return {};
     }
 }
 
@@ -217,7 +217,7 @@ QString Applet::version() const
 {
     Plasma::Applet *app = applet();
     if (!app) {
-        return QString();
+        return {};
     }
 
     return app->pluginMetaData().version();
